#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_DIVFIX_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_DIVFIX_HPP_INCLUDED

#include <boost/simd/arithmetic/include/functions/divfix.hpp>

#endif
